# This file tests the reading capabilities
# using gwosc datasets

import os, sys
import numpy as np
import pandas as pd
from gwdama.io.gwdatamanager import GwDataManager

input_test_glitch_list = "glitch_sample_list_L1_O2.csv"

cwd = os.getcwd()
script_path = os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]))

data_dir = os.path.join(os.path.dirname(script_path),'..',"data")

print("data dir is %s" % data_dir)
input_test_glitch_list = os.path.join(data_dir,input_test_glitch_list)
print("input file list is %s" % input_test_glitch_list)

in_df = pd.read_csv(input_test_glitch_list)
print(in_df)

ifo = np.unique(in_df["ifo"].values)[0]

# init gwdama
gwdama_manager_cvmfs = GwDataManager("test_glitch_gwosc_cvmfs")

for ii in range(len(in_df)):
    t0_gps = in_df.iloc[ii]["GPStime"]
    print("Testing %d (gps=%.4f)" % (ii,t0_gps))
    t1=t0_gps-1
    t2=t0_gps+1
    gwdama_manager_cvmfs.read_gwdata(t1, t2, m_data_source="gwosc-cvmfs", m_channel_name="ht", ifo='L1')

gwdama_manager_cvmfs.write_gwdama_dataset("test_glitch_gwosc_cvmfs_out.h5")


"""
This file is used by the GwDataManager.read_from_virgo() method. It contains
the paths of common ffl in the Virgo Data repository.
It should be kept up to date with the location of the various ffl files.

"""

# ----- Virgo -----
V1_raw = "/virgoData/ffl/raw.ffl"
V1_trend = "/virgoData/ffl/trend.ffl"
V1_trend100 = "/virgoData/ffl/trend100.ffl"


# ----- LIGO -----
L1_newer = "/virgoData/ffl/fromCIT/L1Online.ffl"
H1_newer = "/virgoData/ffl/fromCIT/H1Online.ffl"

L1_older  = "/data/prod/hrec/L1Online/longFiles.ffl"
H1_older  = "/data/prod/hrec/H1Online/longFiles.ffl"

# ----- O3a -----
V1_O3a = "/virgoData/ffl/O3A/V1Online.ffl" # To be updated with V1O3ARepro1A.ffl or V1O3ARepro1A_raw.ffl
H1_O3a = "/virgoData/ffl/O3A/H1Online.ffl"
L1_O3a = "/virgoData/ffl/O3A/L1Online.ffl"

# ----- UniPi -----
unipi_O3 = "/virgoData/ffl/unipi_O3.ffl"         # for rawdata buffer copy
unipi_raw = "/virgoData/ffl/unipi_rawarch.ffl"    # for rawdata archive copy
